@@ -5,7 +5,7 @@ use warnings;
 package MooseX::Enumeration;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.004';
+our $VERSION   = '0.005';
 
 {
 	my $impl;
@@ -97,6 +97,10 @@ This trait gives you a shortcut for specifying an enum type constraint:
 
 =head2 Delegation
 
+=over
+
+=item C<< is >>
+
 The trait also allows you to delegate "is" to the attribute value.
 
    # the most longhanded form...
@@ -115,6 +119,16 @@ Note that above, we might have called the delegated method
 C<< "did_pass" >> instead of C<< "is_pass" >>. You can call it what you
 like.
 
+   has status => (
+      traits    => ["Enumeration"],
+      is        => "rw",
+      enum      => [qw/ pass fail /],
+      handles   => {
+         did_pass    => ["is", "pass"],
+         didnt_pass  => ["is", "fail"],
+      }
+   );
+
 To save typing, we offer some shorthands for common patterns.
 
    has status => (
@@ -154,6 +168,65 @@ We can still go one better...
 
 This will create a delegated method for each value in the enumeration.
 
+As a slightly more advanced option, which will only work for the
+long-hand version, you may match the value against a regular expression
+or any other value that may serve as a right-hand side for a
+L<match::simple> match operation:
+
+   has status => (
+      traits    => ["Enumeration"],
+      is        => "rw",
+      enum      => [qw/ pass fail skip todo /],
+      handles   => {
+         is_pass  => [ "is", qr{^pass$} ],
+         is_fail  => [ "is", "fail" ],
+         is_other => [ "is", [qw(skip todo)] ],
+      }
+   );
+
+=item C<< assign >>
+
+The Enumeration trait allows you to delegate to "assign":
+
+   has status => (
+      traits    => ["Enumeration"],
+      is        => "ro",
+      enum      => [qw/ pass fail unknown /],
+      handles   => {
+         "set_status_pass"  => [ "assign", "pass" ],
+         "set_status_fail"  => [ "assign", "fail" ],
+         "clear_status"     => [ "assign", "unknown" ],
+      }
+   );
+   
+   ...;
+   $obj->set_status_pass;   # sets the object's status to "pass"
+
+It is possible to restrict allowed transitions by adding an extra
+parameter. In the following example you can only set the status to
+"pass" if the current status is "unknown", and you can only set the
+status to "fail" if the current status begins with "u" (effectively
+the same thing).
+
+   has status => (
+      traits    => ["Enumeration"],
+      is        => "ro",
+      enum      => [qw/ pass fail unknown /],
+      handles   => {
+         "set_status_pass"  => [ "assign", "pass", "unknown" ],
+         "set_status_fail"  => [ "assign", "fail", qr{^u} ],
+         "clear_status"     => [ "assign", "unknown" ],
+      }
+   );
+
+Calling C<set_status_pass> if the status is already "pass" is
+conceptually a no-op, so is always allowed.
+
+Methods delegated to C<assign> always return C<< $self >> so are
+suitable for chaining.
+
+=back
+
 =head1 PERFORMANCE
 
 As of version 0.003, C<< $obj->is_pass >> actually benchmarks I<faster>
