@@ -4,7 +4,7 @@ use warnings;
 
 package MooseX::Enumeration::Meta::Method::Accessor::Native::Enumeration::is;
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.004';
+our $VERSION   = '0.005';
 
 use Moose::Role;
 with 'Moose::Meta::Method::Accessor::Native::Reader';
@@ -14,11 +14,13 @@ around _maximum_arguments => sub { 1 };
 
 sub _return_value
 {
+	require match::simple;
+	
 	my $self = shift;
 	my ($slot_access) = @_;
 	# Note that $_[0] comes from @curried which has been closed over
 	# and contains the string we need to compare against.
-	return $slot_access . ' eq $_[0]';
+	return "match::simple::match($slot_access, \$_[0])";
 }
 
 around _generate_method => sub
@@ -32,14 +34,18 @@ around _generate_method => sub
 	if ( @curried==1
 	and defined $curried[0]
 	and not ref $curried[0]
+	and not $self->associated_attribute->is_lazy
 	and $self->_maximum_arguments==1
 	and $self->_minimum_arguments==1 )
 	{
+		my $type = $self->associated_attribute->type_constraint;
+		$type->assert_valid($curried[0]);
+		
 		# ... then provide a highly optimized accessor.
 		require B;
 		require Moose::Util;
 		return sprintf(
-			'sub { %s if @_ > 1; %s eq %s }',
+			'sub { %s if @_ > 1; no warnings qw(uninitialized); %s eq %s }',
 			"Moose::Util::throw_exception('MethodExpectsFewerArgs', 'method_name', 'is', 'maximum_args', 1)",
 			$self->_get_value('$_[0]'),
 			B::perlstring($curried[0]),
